@@ -1,7 +1,7 @@
 
 import json
-import pytz
 import re
+import zoneinfo
 from datetime import datetime, timedelta
 
 from django import template
@@ -35,8 +35,8 @@ def format_datetime(time):
     """
     user_time_zone = timezone.get_current_timezone()
     if time.tzinfo is None:
-        time = time.replace(tzinfo=pytz.utc)
-        user_time_zone = pytz.timezone(getattr(settings, 'USER_TIME_ZONE', 'GMT'))
+        time = time.replace(tzinfo=timezone.utc)
+        user_time_zone = zoneinfo.ZoneInfo(getattr(settings, 'USER_TIME_ZONE', 'GMT'))
 
     time = time.astimezone(user_time_zone)
     return time.strftime("%b %d, %Y %H:%M")
@@ -165,8 +165,8 @@ def map(string, args):
 @register.filter
 def gmail_time(dtime, now=None):
     if dtime.tzinfo is None:
-        dtime = dtime.replace(tzinfo=pytz.utc)
-        user_time_zone = pytz.timezone(getattr(settings, 'USER_TIME_ZONE', 'GMT'))
+        dtime = dtime.replace(tzinfo=timezone.utc)
+        user_time_zone = zoneinfo.ZoneInfo(getattr(settings, 'USER_TIME_ZONE', 'GMT'))
         dtime = dtime.astimezone(user_time_zone)
     else:
         dtime = dtime.astimezone(timezone.get_current_timezone())
@@ -175,7 +175,7 @@ def gmail_time(dtime, now=None):
         now = timezone.now()
 
     if now.tzinfo is None:
-        now = now.replace(tzinfo=pytz.utc)
+        now = now.replace(tzinfo=timezone.utc)
 
     twelve_hours_ago = now - timedelta(hours=12)
 
